SqliteDataSource class

Implementasi LensDataSource untuk database SQLite (sqflite).

Implemented types

Constructors

SqliteDataSource({required String sourceId, required String sourceName, required Database database})

Properties

database → Database
Instance sqflite mentah (hanya untuk integrasi legacy).
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceId String
no setteroverride
sourceName String
no setteroverride
sourceType SourceType
no setteroverride

Methods

allRows(String collection) Future<List<Map<String, dynamic>>>
Ambil semua baris (untuk ekspor).
override
collections() Future<List<String>>
override
columnNames(String collection) Future<List<String>>
Nama kolom untuk header tabel UI.
override
count(String collection) Future<int>
override
execute(String sql) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rawQuery(String sql) Future<List<Map<String, dynamic>>>
override
rawQueryCount(String sql) Future<int>
override
rawQueryPaged(String sql, {required int limit, required int offset}) Future<List<Map<String, dynamic>>>
override
rows(String collection, int limit, int offset) Future<List<Map<String, dynamic>>>
override
toString() String
A string representation of this object.
inherited
updateCell(String collection, String column, Object? newValue, Map<String, dynamic> row) Future<void>
Perbarui nilai satu sel. Implementasi spesifik per engine.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited