HistoryDataSource class
CRUD langsung ke tabel history_entries.
Constructors
- HistoryDataSource(HistoryDatabase _database)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAll(
) → Future< void> -
clearForSource(
String sourceId) → Future< void> -
getForSource(
String sourceId, {int? limit}) → Future< List< HistoryEntry> > -
insertEntries(
List< HistoryEntry> entries) → Future<void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pruneForSource(
String sourceId, {int? maxEntries, Duration? maxAge}) → Future< void> -
Buang entri lama milik
sourceIdberdasarkan usia (maxAge) dan/atau jumlah maksimum (maxEntries) yang masih boleh disimpan. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited