GetRowsUseCase class

Mengambil baris dengan pagination dari satu koleksi.

Constructors

GetRowsUseCase(LensRepository _repository)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String sourceId, String collection, int limit, int offset) Future<List<RowEntity>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited