DbLensController class
Facade headless yang menggabungkan controller kecil (source, table, query, queryHistory, edit, browse).
Dipakai penuh lewat DbLensPanel/DbLens.open, atau dibongkar untuk UI custom lewat DbLensControllerScope — ambil sub-controller yang relevan saja, tidak wajib depend ke semuanya.
- Inheritance
-
- Object
- ChangeNotifier
- DbLensController
Constructors
- DbLensController({required LensRepository repository, DbLensConfig config = const DbLensConfig()})
Properties
-
activeColumns
→ List<
String> -
no setter
- activeRowCount → int
-
no setter
-
activeRows
→ List<
Map< String, Object?> > -
no setter
- browse → DbLensBrowseController
-
final
- canCopyJson → bool
-
no setter
- canEditCells → bool
-
no setter
- canRefresh → bool
-
no setter
- config → DbLensConfig
-
final
- copyingJson ↔ bool
-
getter/setter pair
- edit → DbLensEditController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isInitialized → bool
-
Apakah initialize sudah pernah dipanggil dan selesai.
no setter
- lastError ↔ String?
-
Error terbaru dari salah satu sub-controller (untuk ditampilkan sekali
lewat snackbar lalu di-clear). Set null untuk clear semuanya.
getter/setter pair
- query → DbLensQueryController
-
final
- queryHistory → DbLensQueryHistoryController
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → DbLensSourceController
-
final
- table → DbLensTableController
-
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
copyAllAsJson(
) → Future< String?> -
dispose(
) → void -
Discards any resources used by the object.
override
-
initialize(
) → Future< void> -
loadBrowseSnapshot(
) → Future< List< BrowseSourceSnapshot> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
refresh(
) → Future< void> -
refreshBrowse(
) → Future< void> -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
restoreTableView(
) → void -
runQuery(
{bool fromRefresh = false}) → Future< void> -
selectCollection(
String collection) → Future< void> -
selectSource(
String sourceId) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
updateCellValue(
{required String column, required Object? newValue, required Map< String, Object?> row}) → Future<bool> -
updateRowFromJson(
Map< String, Object?> originalRow, Map<String, Object?> updatedRow) → Future<String?> -
visibleRows(
{required List< String> columns}) → List<Map< String, Object?> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited