DbLensQueryHistoryEntry class

Satu entri riwayat eksekusi query — beda konsep dari HistoryEntry (yang melacak perubahan baris). Ini melacak perintah SQL yang pernah dijalankan konsumen lewat DbLensQueryController.

Constructors

DbLensQueryHistoryEntry({required String sql, required bool isError, required DateTime createdAt, String? info, String? table})
const

Properties

createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
info String?
final
isError bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sql String
final
table String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited