DbLensSourceController class

Mengelola daftar source, source terpilih, dan koleksinya.

Tidak tahu apa-apa soal pagination, query, atau edit — cukup depend ke LensRepository untuk daftar source/collection.

Inheritance

Constructors

DbLensSourceController({required LensRepository repository})

Properties

collections List<String>
getter/setter pair
collectionSearchText String
getter/setter pair
filteredCollections List<String>
no setter
filteredSourceNames List<String>
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hasSources bool
no setter
lastError String?
getter/setter pair
loading bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedCollection String?
getter/setter pair
selectedSourceId String?
getter/setter pair
selectedSourceName String?
no setter
selectedSourceType SourceType?
no setter
sourceNames List<String>
no setter
sources List<SourceEntity>
getter/setter pair
sourceSearchText String
getter/setter pair
supportsRawSql bool
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
initialize() Future<void>
loadCollections(String sourceId) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
selectCollection(String collection) → void
selectSource(String sourceId) Future<void>
setCollectionSearchText(String value) → void
setSourceSearchText(String value) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited