DbLensTableViewCache class
Snapshot ringan untuk restore view tabel setelah query mode.
Constructors
-
DbLensTableViewCache({required List<
String> columns, required String? columnsTable}) -
const
Properties
-
columns
→ List<
String> -
final
- columnsTable → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited