DbLensTheme class

Instance tema yang dapat dikonfigurasi untuk panel DB Lens.

Constructors

DbLensTheme([DbLensThemeData? data])

Properties

accent Color
no setter
accentSoft Color
no setter
bg Color
no setter
border Color
no setter
data DbLensThemeData
final
diffAdded Color
no setter
diffChanged Color
no setter
diffRemoved Color
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surface Color
no setter
syntaxBool Color
no setter
syntaxDefault Color
no setter
syntaxNull Color
no setter
syntaxNumber Color
no setter
syntaxString Color
no setter
textMuted Color
no setter
textPrimary Color
no setter
textSecondary Color
no setter

Methods

fieldDecoration({required String hintText, Widget? prefixIcon, Widget? suffixIcon, Color? fillColor}) InputDecoration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
outlineBorder({Color? color}) OutlineInputBorder
sheetDecoration({double size = 0}) BoxDecoration
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

cellMinWidth → const double
cellPaddingH → const double
cellPaddingV → const double
dataFontSize → const double
dismissThreshold → const double
headerFontSize → const double
indexColWidth → const double
initialChildSize → const double
maxChildSize → const double
minChildSize → const double
sheetRadius → const Radius
sheetShadow → const BoxShadow