DbLensThemeData class
Konfigurasi warna dan token desain yang dapat disesuaikan untuk panel DB Lens.
Constructors
- DbLensThemeData({Color bg = const Color(0xFFFFFFFF), Color surface = const Color(0xFFF5F7FA), Color border = const Color(0xFFE5E7EB), Color textPrimary = const Color(0xFF111827), Color textSecondary = const Color(0xFF6B7280), Color textMuted = const Color(0xFF9CA3AF), Color accent = const Color(0xFF6366F1), Color accentSoft = const Color(0xFFEEF2FF), Color syntaxNull = const Color(0xFF9CA3AF), Color syntaxString = const Color(0xFF16A34A), Color syntaxNumber = const Color(0xFFD97706), Color syntaxBool = const Color(0xFF2563EB), Color syntaxDefault = const Color(0xFF111827), Color diffAdded = const Color(0xFF16A34A), Color diffRemoved = const Color(0xFFDC2626), Color diffChanged = const Color(0xFFD97706)})
-
const
- DbLensThemeData.fromMaterialTheme(ThemeData theme)
-
factory
Properties
- accent → Color
-
final
- accentSoft → Color
-
final
- bg → Color
-
final
- border → Color
-
final
- diffAdded → Color
-
Warna field yang ditambahkan (insert / hanya ada di "after").
final
- diffChanged → Color
-
Warna field yang nilainya berubah (update).
final
- diffRemoved → Color
-
Warna field yang dihapus (delete / hanya ada di "before").
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- surface → Color
-
final
- syntaxBool → Color
-
final
- syntaxDefault → Color
-
final
- syntaxNull → Color
-
final
- syntaxNumber → Color
-
final
- syntaxString → Color
-
final
- textMuted → Color
-
final
- textPrimary → Color
-
final
- textSecondary → Color
-
final
Methods
-
copyWith(
{Color? bg, Color? surface, Color? border, Color? textPrimary, Color? textSecondary, Color? textMuted, Color? accent, Color? accentSoft, Color? syntaxNull, Color? syntaxString, Color? syntaxNumber, Color? syntaxBool, Color? syntaxDefault, Color? diffAdded, Color? diffRemoved, Color? diffChanged}) → DbLensThemeData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const DbLensThemeData
- Nilai default — sama dengan token hardcoded asli.