DbLensDiffField class

One field diff result.

Constructors

DbLensDiffField({required String key, required Object? beforeValue, required Object? afterValue, required DbLensDiffKind kind})
const

Properties

afterValue Object?
final
beforeValue Object?
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
kind DbLensDiffKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited