DbLensHistoryDiffUtils class

Computes field-level diffs from history entry JSON snapshots.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compute({String? beforeJson, String? afterJson, List<String>? changedColumns}) List<DbLensDiffField>