Utilitas untuk menyiapkan data baris sebagai JSON yang dapat dibaca.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
encodePretty(
Map< String, Object?> row) → String - Encode baris sebagai pretty-printed JSON.
-
encodePrettyArray(
List< Map< rows) → StringString, Object?> > - Encode daftar baris sebagai pretty-printed JSON array.
-
looksLikeJson(
String value) → bool -
normalizeValue(
Object? value) → Object? - Normalisasi nilai — deteksi dan parse string yang berisi JSON.
-
parseRowJson(
String source) → Map< String, Object?> - Parse teks JSON hasil edit menjadi map baris.
-
prepareRow(
Map< String, Object?> row) → Map<String, Object?> - Siapkan baris untuk tampilan JSON — hapus kolom internal dan parse string JSON.