RowUtils class abstract final

Utilitas format, warna, pencarian, dan sort baris di UI.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

applySearchAndSort({required List<Map<String, Object?>> rows, required List<String> columns, required String searchText, required String? sortColumn, required bool sortAscending}) List<Map<String, Object?>>
compareValues(Object? a, Object? b) int
filterItems(List<String> items, String query) List<String>
formatValue(Object? value) String
normalizeValue(Object? value) String
valueColor(Object? value, [DbLensTheme? theme]) Color