DbLensTableView class

Preset DbLensDataGrid untuk tampilan tabel browse standar — kolom nomor baris + header yang bisa di-tap untuk sort.

Murni presentational: menerima data + callback, tidak menerima controller apa pun.

Inheritance

Constructors

DbLensTableView({Key? key, required List<Map<String, Object?>> rows, required List<String> columns, int rowNumberStart = 1, String? sortColumn, bool sortAscending = true, ValueChanged<String>? onSort, void onRowTap(Map<String, Object?> row)?, void onCellLongPress(String column, Map<String, Object?> row)?, void onIndexLongPress(Map<String, Object?> row)?})
const

Properties

columns List<String>
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCellLongPress → void Function(String column, Map<String, Object?> row)?
final
onIndexLongPress → void Function(Map<String, Object?> row)?
final
onRowTap → void Function(Map<String, Object?> row)?
final
onSort ValueChanged<String>?
final
rowNumberStart int
final
rows List<Map<String, Object?>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortAscending bool
final
sortColumn String?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited