DbLensConfig class
Konfigurasi panel DbLens (pagination, prefetch, dll.).
Constructors
- DbLensConfig({int pageSize = defaultPageSize, bool enablePrefetch = true, bool enableHistory = true, Duration historyPollInterval = defaultHistoryPollInterval, DbLensPresentationMode presentationMode = DbLensPresentationMode.bottomSheet, bool fullscreenDialog = true})
-
const
Properties
- enableHistory → bool
-
Aktifkan pelacakan riwayat perubahan data (nonaktif di release build).
final
- enablePrefetch → bool
-
Prefetch halaman berikutnya di background.
final
- fullscreenDialog → bool
-
Only used when presentationMode is DbLensPresentationMode.fullPage.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- historyPollInterval → Duration
-
Interval polling untuk deteksi perubahan data.
final
- pageSize → int
-
Jumlah baris per halaman (1–maxPageSize).
final
- presentationMode → DbLensPresentationMode
-
Mode presentasi default saat dipanggil lewat DbLens.open.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHistoryPollInterval → const Duration
- defaultPageSize → const int
- maxPageSize → const int