DbLensConfig class

Konfigurasi panel DbLens (pagination, prefetch, dll.).

Constructors

DbLensConfig({int pageSize = defaultPageSize, bool enablePrefetch = true})
const

Properties

enablePrefetch bool
Prefetch halaman berikutnya di background.
final
hashCode int
The hash code for this object.
no setterinherited
pageSize int
Jumlah baris per halaman (1–maxPageSize).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultPageSize → const int
maxPageSize → const int