Utilitas deteksi jenis perintah SQL (presentation/domain agnostic).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
containsDangerousKeyword(
String sql) → bool -
extractSimpleFromTable(
String sql) → String? - Ekstrak nama tabel tunggal dari klausa FROM pada SELECT sederhana.
-
isComplexSelectQuery(
String sql) → bool - Apakah query terlalu kompleks untuk auto-select tabel (JOIN, subquery, dll.).
-
isSelectQuery(
String sql) → bool -
requiresConfirmation(
String sql) → bool