LensDataSource class abstract
Abstraksi akses data per engine penyimpanan.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceId → String
-
no setter
- sourceName → String
-
no setter
- sourceType → SourceType
-
no setter
Methods
-
allRows(
String collection) → Future< List< Map< >String, dynamic> > - Ambil semua baris (untuk ekspor).
-
collections(
) → Future< List< String> > -
columnNames(
String collection) → Future< List< String> > - Nama kolom untuk header tabel UI.
-
count(
String collection) → Future< int> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rows(
String collection, int limit, int offset) → Future< List< Map< >String, dynamic> > -
toString(
) → String -
A string representation of this object.
inherited
-
updateCell(
String collection, String column, Object? newValue, Map< String, dynamic> row) → Future<void> - Perbarui nilai satu sel. Implementasi spesifik per engine.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited