SqlQueryableDataSource class abstract
Kemampuan query SQL mentah — hanya untuk engine berbasis SQL.
- Implemented types
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceId → String
-
no setterinherited
- sourceName → String
-
no setterinherited
- sourceType → SourceType
-
no setterinherited
Methods
-
allRows(
String collection) → Future< List< Map< >String, dynamic> > -
Ambil semua baris (untuk ekspor).
inherited
-
collections(
) → Future< List< String> > -
inherited
-
columnNames(
String collection) → Future< List< String> > -
Nama kolom untuk header tabel UI.
inherited
-
count(
String collection) → Future< int> -
inherited
-
execute(
String sql) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rawQuery(
String sql) → Future< List< Map< >String, dynamic> > -
rawQueryCount(
String sql) → Future< int> -
rawQueryPaged(
String sql, {required int limit, required int offset}) → Future< List< Map< >String, dynamic> > -
rows(
String collection, int limit, int offset) → Future< List< Map< >String, dynamic> > -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateCell(
String collection, String column, Object? newValue, Map< String, dynamic> row) → Future<void> -
Perbarui nilai satu sel. Implementasi spesifik per engine.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited