DbLensListView class
Expandable row cards — preview columns, copy JSON, search highlight, edit.
When onEditCell is omitted, DbLensCellEdit.run is used automatically (via onSaveCell, controller, or nearest DbLensControllerScope).
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- DbLensListView
Constructors
-
DbLensListView({Key? key, required List<
Map< rows, required List<String, Object?> >String> columns, int rowNumberStart = 1, int previewColumnCount = 2, String searchQuery = '', bool canEditColumn(String column)?, Future<void> onEditCell(String column, Object? currentValue, Map<String, Object?> row)?, Future<bool> onSaveCell(String column, Object? newValue, Map<String, Object?> row)?, DbLensController? controller, bool? isSQLite, void onCopyRow(Map<String, Object?> row)?, DbLensValueRenderer? valueRenderer, EdgeInsets padding = const EdgeInsets.all(12)}) -
const
Properties
- canEditColumn → bool Function(String column)?
-
final
-
columns
→ List<
String> -
final
- controller → DbLensController?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSQLite → bool?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onCopyRow
→ void Function(Map<
String, Object?> row)? -
final
-
onEditCell
→ Future<
void> Function(String column, Object? currentValue, Map<String, Object?> row)? -
final
-
onSaveCell
→ Future<
bool> Function(String column, Object? newValue, Map<String, Object?> row)? -
final
- padding → EdgeInsets
-
final
- previewColumnCount → int
-
final
- rowNumberStart → int
-
final
-
rows
→ List<
Map< String, Object?> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchQuery → String
-
final
- valueRenderer → DbLensValueRenderer?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultEditCell(
BuildContext context, {required String column, required Object? currentValue, required Map< String, Object?> row, Future<bool> onSave(String column, Object? newValue, Map<String, Object?> row)?, DbLensController? controller, bool? isSQLite}) → Future<void> - Default edit handler — dialog + save via controller or onSaveCell.