DbLensQueryConsole class
Halaman konsol SQL penuh — editor gelap, riwayat, grid hasil, salin CSV/JSON.
Berdiri sendiri lewat DbLens.runRawQuery / DbLens.executeStatement (tanpa DbLensController). Bungkus dengan DbLensThemeScope.
DbLensQueryConsole.push(
context,
source: 'Main DB',
tableNames: ['users', 'orders'],
);
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DbLensQueryConsole
Constructors
-
DbLensQueryConsole({Key? key, required String source, List<
String> tableNames = const [], DbLensQueryHistoryController? historyController, DbLensQueryConfirmBuilder? confirmBuilder, VoidCallback? onBack}) -
const
Properties
- confirmBuilder → DbLensQueryConfirmBuilder?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- historyController → DbLensQueryHistoryController?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onBack → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
sourceId atau sourceName.
final
-
tableNames
→ List<
String> -
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DbLensQueryConsole> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
push<
T> (BuildContext context, {required String source, List< String> tableNames = const [], DbLensQueryHistoryController? historyController, DbLensQueryConfirmBuilder? confirmBuilder}) → Future<T?>